# Your Bot

This repository contains the configuration for the <...> GitHub bot. It is based
on [baldrick](https://github.com/astrofrog/baldrick).

### Requirements

This app requires Python 3.6 to run, and dependencies are listed in
``requirements.txt``
